@@ -16,12 +16,12 @@ def process():
             "country_code": "AT",
             "primary": True,
             "bic": row[18].strip().upper(),
-            "bank_code": row[2].strip(),
+            "bank_code": row[2].strip().rjust(5, "0"),
             "name": row[6].strip(),
             "short_name": row[6].strip(),
         }
         for i, row in enumerate(csvfile)
-        if i >= 6 and len(row) == 21
+        if i >= 6 and len(row) >= 19
     ]
 
 
